@@ -91,7 +91,7 @@ on_album_artist_focus_out_event        (GtkWidget       *widget,
         fatalError("malloc(sizeof(gchar) * (strlen(ctext) + 1)) failed. Out of memory.");
     strncpy(text, ctext, strlen(ctext)+1);
     
-    trim_chars(text, BADCHARS);		// lnr
+    //trim_chars(text, BADCHARS);		// lnr	//Commented out by mrpl
     trim_whitespace(text);
     
     if(text[0] == '\0')
@@ -138,7 +138,7 @@ on_album_title_focus_out_event         (GtkWidget       *widget,
         fatalError("malloc(sizeof(gchar) * (strlen(ctext) + 1)) failed. Out of memory.");
     strncpy(text, ctext, strlen(ctext)+1);
     
-    trim_chars(text, BADCHARS);		// lnr
+    //trim_chars(text, BADCHARS);		// lnr	//Commented out by mrpl
     trim_whitespace(text);
     
     if(text[0] == '\0')
@@ -165,7 +165,7 @@ on_album_genre_focus_out_event         (GtkWidget       *widget,
 
     strncpy(text, ctext, strlen(ctext)+1);
     
-    trim_chars(text, BADCHARS);		// lnr
+    //trim_chars(text, BADCHARS);		// lnr	//Commented out by mrpl
     trim_whitespace(text);
     
     if(text[0] == '\0')
@@ -188,7 +188,7 @@ on_artist_edited                    (GtkCellRendererText *cell,
                     GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
     GtkTreeIter iter;
     
-    trim_chars(new_text, BADCHARS);		// lnr
+    //trim_chars(new_text, BADCHARS);		// lnr	//Commented out by mrpl
     trim_whitespace(new_text);
     
     gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(store), &iter, path_string);
@@ -210,7 +210,7 @@ on_genre_edited                    (GtkCellRendererText *cell,
                     GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
     GtkTreeIter iter;
     
-    trim_chars(new_text, BADCHARS);
+    //trim_chars(new_text, BADCHARS);	//Commented out by mrpl
     trim_whitespace(new_text);
     
     gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(store), &iter, path_string);
@@ -290,6 +290,15 @@ on_mp3bitrate_value_changed            (GtkRange        *range,
     gtk_label_set_text(GTK_LABEL(lookup_widget(win_prefs, "bitrate_lbl_2")), bitrate);
 }
 
+void
+on_opusrate_value_changed           (GtkRange   *range,
+                                     gpointer   user_data)
+{
+    char bitrate[8];
+    snprintf(bitrate, 8, _("%dKbps"), int_to_bitrate((int)gtk_range_get_value(range), FALSE));
+    gtk_label_set_text(GTK_LABEL(lookup_widget(win_prefs, "bitrate_lbl_4")), bitrate);
+}
+
 void
 on_musepackbitrate_value_changed            (GtkRange        *range,
                                              gpointer         user_data)
@@ -483,6 +492,32 @@ on_rip_ogg_toggled                     (GtkToggleButton *togglebutton,
         enable_ogg_widgets();
 }
 
+void
+on_rip_opus_toggled                     (GtkToggleButton *togglebutton,
+                                        gpointer user_data)
+{
+    if (gtk_toggle_button_get_active(togglebutton) && !program_exists("opusenc"))
+    {
+        GtkWidget *dialog;
+        dialog = gtk_message_dialog_new(GTK_WINDOW(win_main),
+                                        GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                        _("%s was not found in your path. Asunder requires it to create %s files. "
+                                          "All %s functionality is disabled."),
+                                        "'opusenc'", "OPUS", "opus");
+        gtk_dialog_run (GTK_DIALOG(dialog));
+        gtk_widget_destroy(dialog);
+
+        global_prefs->rip_opus=0;
+        gtk_toggle_button_set_active(togglebutton, global_prefs->rip_opus);
+
+    }
+
+    if (!gtk_toggle_button_get_active(togglebutton))
+        disable_opus_widgets();
+    else
+        enable_opus_widgets();
+}
+
 void
 on_rip_wavpack_toggled                 (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
@@ -638,7 +673,7 @@ on_title_edited                    (GtkCellRendererText *cell,
                     GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
     GtkTreeIter iter;
     
-    trim_chars(new_text, BADCHARS);		// lnr
+    //trim_chars(new_text, BADCHARS);		// lnr	//Commented out by mrpl
     trim_whitespace(new_text);
     
     gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(store), &iter, path_string);
@@ -679,7 +714,7 @@ on_tracklist_mouse_click               (GtkWidget* treeView,
         gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL,
                        event->button, gdk_event_get_time((GdkEvent*)event));
         
-        /* no need for signal to propagete */
+        /* no need for signal to propagate */
         return TRUE;
     }
     
