@@ -543,13 +543,29 @@ create_prefs (void)
     gtk_container_add (GTK_CONTAINER (notebook1), vbox);
     
     /* WAV */
+    //frame3 = gtk_frame_new (NULL);
+    //gtk_frame_set_shadow_type(GTK_FRAME(frame3), GTK_SHADOW_IN);
+    //gtk_widget_show (frame3);
+    //gtk_box_pack_start (GTK_BOX (vbox), frame3, FALSE, FALSE, 0);
+    
+    //alignment8 = gtk_alignment_new (0.5, 0.5, 1, 1);
+    //gtk_widget_show (alignment8);
+    //gtk_container_add (GTK_CONTAINER (frame3), alignment8);
+    //gtk_alignment_set_padding (GTK_ALIGNMENT (alignment8), 2, 2, 12, 2);
+    
+    //vbox2 = gtk_vbox_new (FALSE, 0);
+    //gtk_widget_show (vbox2);
+    //gtk_container_add (GTK_CONTAINER (alignment8), vbox2);
+    
     rip_wav = gtk_check_button_new_with_mnemonic (_("WAV (uncompressed)"));
     gtk_widget_show (rip_wav);
     gtk_box_pack_start (GTK_BOX (vbox), rip_wav, FALSE, FALSE, 0);
+    //gtk_frame_set_label_widget (GTK_FRAME (frame3), rip_wav);
     /* END WAV */
     
     /* MP3 */
     frame3 = gtk_frame_new (NULL);
+    gtk_frame_set_shadow_type(GTK_FRAME(frame3), GTK_SHADOW_IN);
     gtk_widget_show (frame3);
     gtk_box_pack_start (GTK_BOX (vbox), frame3, FALSE, FALSE, 0);
 
@@ -610,6 +626,7 @@ create_prefs (void)
     
     /* OGG */
     frame4 = gtk_frame_new (NULL);
+    gtk_frame_set_shadow_type(GTK_FRAME(frame4), GTK_SHADOW_IN);
     gtk_widget_show (frame4);
     gtk_box_pack_start (GTK_BOX (vbox), frame4, FALSE, FALSE, 0);
 
@@ -645,6 +662,7 @@ create_prefs (void)
 
     /* FLAC */
     frame5 = gtk_frame_new (NULL);
+    gtk_frame_set_shadow_type(GTK_FRAME(frame5), GTK_SHADOW_IN);
     gtk_widget_show (frame5);
     gtk_box_pack_start (GTK_BOX (vbox), frame5, FALSE, FALSE, 0);
 
@@ -708,6 +726,7 @@ create_prefs (void)
     char opus_kbps[10];
 
     opus_frame = gtk_frame_new(NULL);
+    gtk_frame_set_shadow_type(GTK_FRAME(opus_frame), GTK_SHADOW_IN);
     gtk_widget_show (opus_frame);
     gtk_box_pack_start (GTK_BOX(hiddenbox), opus_frame, FALSE, FALSE, 0);
 
@@ -755,6 +774,7 @@ create_prefs (void)
     GtkWidget* flacVbox;
     
     frame6 = gtk_frame_new (NULL);
+    gtk_frame_set_shadow_type(GTK_FRAME(frame6), GTK_SHADOW_IN);
     gtk_widget_show (frame6);
     gtk_box_pack_start (GTK_BOX (hiddenbox), frame6, FALSE, FALSE, 0);
     
@@ -836,6 +856,7 @@ create_prefs (void)
     GtkWidget* musepackVbox;
     
     frame9 = gtk_frame_new (NULL);
+    gtk_frame_set_shadow_type(GTK_FRAME(frame9), GTK_SHADOW_IN);
     gtk_widget_show (frame9);
     gtk_box_pack_start (GTK_BOX (hiddenbox), frame9, FALSE, FALSE, 0);
     
@@ -892,6 +913,7 @@ create_prefs (void)
     GtkWidget* monkeyVbox;
     
     frame8 = gtk_frame_new (NULL);
+    gtk_frame_set_shadow_type(GTK_FRAME(frame8), GTK_SHADOW_IN);
     gtk_widget_show (frame8);
     gtk_box_pack_start (GTK_BOX (hiddenbox), frame8, FALSE, FALSE, 0);
     
@@ -947,6 +969,7 @@ create_prefs (void)
     GtkWidget* aacVbox;
     
     frame8 = gtk_frame_new (NULL);
+    gtk_frame_set_shadow_type(GTK_FRAME(frame8), GTK_SHADOW_IN);
     gtk_widget_show (frame8);
     gtk_box_pack_start (GTK_BOX (hiddenbox), frame8, FALSE, FALSE, 0);
     
@@ -1003,6 +1026,7 @@ create_prefs (void)
     GtkWidget* portNum;
     GtkWidget* frameVbox;
     GtkWidget* do_log;
+    GtkWidget* do_fast_rip;
     
     vbox = gtk_vbox_new (FALSE, 5);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
@@ -1010,6 +1034,7 @@ create_prefs (void)
     gtk_container_add (GTK_CONTAINER (notebook1), vbox);
     
     frame = gtk_frame_new (NULL);
+    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
     gtk_frame_set_label(GTK_FRAME(frame), "CDDB");
     gtk_widget_show (frame);
     gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
@@ -1055,6 +1080,7 @@ create_prefs (void)
     gtk_tooltips_set_tip (tooltips, cddbPortNum, _("The CDDB server port (default is 8880)"), NULL);
     
     frame = gtk_frame_new (NULL);
+    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
     gtk_widget_show (frame);
     gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
     
@@ -1093,11 +1119,16 @@ create_prefs (void)
     gtk_box_pack_start (GTK_BOX (hbox), portNum, TRUE, TRUE, 5);
     GLADE_HOOKUP_OBJECT (prefs, portNum, "port_number");
     
-    do_log = gtk_check_button_new_with_label ("Log to /var/log/asunder.log");
+    do_log = gtk_check_button_new_with_label (_("Log to /var/log/asunder.log"));
     gtk_widget_show (do_log);
     gtk_box_pack_start (GTK_BOX (vbox), do_log, FALSE, FALSE, 0);
     GLADE_HOOKUP_OBJECT (prefs, do_log, "do_log");
     
+    do_fast_rip = gtk_check_button_new_with_label (_("Faster ripping (no error correction)"));
+    gtk_widget_show (do_fast_rip);
+    gtk_box_pack_start (GTK_BOX (vbox), do_fast_rip, FALSE, FALSE, 0);
+    GLADE_HOOKUP_OBJECT (prefs, do_fast_rip, "do_fast_rip");
+    
     hboxFill = gtk_hbox_new (FALSE, 0);
     gtk_widget_show (hboxFill);
     gtk_box_pack_start (GTK_BOX (vbox), hboxFill, TRUE, TRUE, 0);
@@ -1407,7 +1438,7 @@ void enable_musepack_widgets(void)
 }
 
 const char* 
-GBLprogramName = "Asunder 2.5";
+GBLprogramName = "Asunder 2.7";
 
 static const char* 
 GBLauthors[2] = {
@@ -1466,6 +1497,9 @@ GBLauthors[2] = {
 "Felix Braun\n"
 "- Support for encoding into OPUS.\n"
 "\n"
+"Nicolas Leveille\n"
+"- Fix for: don't reset the track info edited by the user by doing an unnecessary CDDB lookup.\n"
+"\n"
 "Packages:\n"
 "\n"
 "Toni Graffy\n"
@@ -1550,7 +1584,7 @@ GBLtranslators =
 "- cs (Czeck) translation of Asunder versions 0.8 - 1.0, 1.9\n"
 "\n"
 "Petr Simacek\n"
-"- cs (Czeck) translation of Asunder version 2.2\n"
+"- cs (Czeck) translation of Asunder versions 2.2, 2.5\n"
 "\n"
 "Joe Hansen\n"
 "- da (Danish) translation of Asunder version 1.9\n"
@@ -1595,10 +1629,10 @@ GBLtranslators =
 "- fr (French) translation of Asunder versions 2.1 - 2.2\n"
 "\n"
 "Miguel Anxo Bouzada\n"
-" - gl (Galician) translation of Asunder version 2.2\n"
+"- gl (Galician) translation of Asunder version 2.2\n"
 "\n"
 "Genghis Khan\n"
-" - he (Hebrew) translation of Asunder version 2.2\n"
+"- he (Hebrew) translation of Asunder version 2.2\n"
 "\n"
 "Peter Polonkai\n"
 "- hu (Hungarian) translation of Asunder versions 0.8 - 1.9\n"
@@ -1630,6 +1664,9 @@ GBLtranslators =
 "Robert Groenning\n"
 "- nb (Norwegian Bokmal) translation of Asunder version 0.8\n"
 "\n"
+"Aka Sikrom\n"
+"- nb (Norwegian Bokmal) translation of Asunder version 2.5\n"
+"\n"
 "Wolven\n"
 "- nb (Norwegian Bokmal) translation of Asunder version 1.6\n"
 "\n"
@@ -1706,6 +1743,9 @@ GBLtranslators =
 "Tiansworld\n"
 "- zh_CN (Simplified Chineese) translation of Asunder version 2.3\n"
 "\n"
+"Jeff Bai\n"
+"- zh_CN (Simplified Chineese) translation of Asunder version 2.5\n"
+"\n"
 "Cheng-Wei Chien\n"
 "- zh_TW (Chineese/Taiwan) translation of Asunder versions 0.8 - 1.9\n"
 "\n";
